"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const marketplace_command_1 = tslib_1.__importDefault(require("../../marketplace-command"));
const services_1 = tslib_1.__importDefault(require("../../services"));
class MarketplaceCreateOffer extends marketplace_command_1.default {
    async run() {
        const { args, flags } = this.parse(MarketplaceCreateOffer);
        const account = await this.getAccount();
        const passphrase = await this.getPassphrase();
        this.spinner.start('Creating offer');
        const prepareOffer = await this.executeAndCaptureError(services_1.default.marketplace.id, services_1.default.marketplace.tasks.prepareCreateOffer, {
            sid: args.SID,
            price: flags.price,
            duration: flags.duration,
            from: account,
        });
        const signedTx = await this.sign(account, prepareOffer.data, passphrase);
        const offer = await this.executeAndCaptureError(services_1.default.marketplace.id, services_1.default.marketplace.tasks.publishCreateOffer, signedTx);
        this.spinner.stop('Offer created');
        this.styledJSON(offer.data);
        return offer.data;
    }
}
MarketplaceCreateOffer.description = 'Create a new offer on a service on the MESG Marketplace';
MarketplaceCreateOffer.flags = Object.assign({}, marketplace_command_1.default.flags, { price: command_1.flags.string({
        description: 'Price (in MESG token) of the offer to create',
        required: true,
    }), duration: command_1.flags.string({
        description: 'Duration (in second) of the offer to create',
        required: true,
    }) });
MarketplaceCreateOffer.args = [{
        name: 'SID',
        description: 'SID of the service on the MESG Marketplace',
        required: true,
    }];
exports.default = MarketplaceCreateOffer;
