"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const js_yaml_1 = tslib_1.__importDefault(require("js-yaml"));
const path_1 = require("path");
const deployer_1 = tslib_1.__importDefault(require("../../deployer"));
const service_command_1 = tslib_1.__importDefault(require("../../service-command"));
const publish_1 = tslib_1.__importDefault(require("../marketplace/publish"));
class ServiceCompile extends service_command_1.default {
    async run() {
        const { args } = this.parse(ServiceCompile);
        this.spinner.status = 'Download sources';
        const path = await deployer_1.default(await this.processUrl(args.SERVICE_PATH_OR_URL));
        const source = await new publish_1.default(this.argv, this.config).deploySources(path);
        const definition = this.parseYml(fs_1.readFileSync(path_1.join(path, 'mesg.yml')).toString(), source);
        this.styledJSON(definition);
        this.spinner.stop();
        return definition;
    }
    parseYml(content, source) {
        const o = js_yaml_1.default.safeLoad(content);
        const parseParams = (params) => Object.keys(params || {})
            .map((key) => {
            const { name, description, type, repeated, optional, object } = params[key];
            return { key, name, description, type, repeated, optional, object: parseParams(object || {}) };
        });
        return {
            sid: o.sid,
            name: o.name,
            description: o.description,
            tasks: Object.keys(o.tasks || {}).map((key) => {
                const { name, description, inputs, outputs } = o.tasks[key];
                return { key, name, description, inputs: parseParams(inputs), outputs: parseParams(outputs) };
            }),
            events: Object.keys(o.events || {}).map((key) => {
                const { name, description, data } = o.events[key];
                return { key, name, description, data: parseParams(data) };
            }),
            dependencies: Object.keys(o.dependencies || {}).map((key) => (Object.assign({ key }, o.dependencies[key]))),
            configuration: o.configuration,
            repository: o.repository,
            source
        };
    }
    async processUrl(url) {
        const marketplaceUrl = url.split('mesg://marketplace/service/');
        if (marketplaceUrl.length === 2) {
            const versionHash = marketplaceUrl[1];
            const { type, source } = await this.getAuthorizedServiceInfo('', versionHash);
            if (type === 'ipfs') {
                return `http://ipfs.app.mesg.com:8080/ipfs/${source}`; // tslint:disable-line:no-http-string
            }
            throw new Error(`unknown protocol '${type}'`);
        }
        return url;
    }
}
ServiceCompile.description = 'Compile a service and upload its source to IPFS';
ServiceCompile.flags = Object.assign({}, service_command_1.default.flags);
ServiceCompile.args = [{
        name: 'SERVICE_PATH_OR_URL',
        description: 'Path of the service or url to access it',
        default: './'
    }];
ServiceCompile.hidden = true;
exports.default = ServiceCompile;
