"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const service_command_1 = tslib_1.__importDefault(require("../../service-command"));
class ServiceDelete extends service_command_1.default {
    async run() {
        const { argv, flags } = this.parse(ServiceDelete);
        if (!flags['keep-data']) {
            cli_ux_1.default.warn('This will delete all data associated to this service');
        }
        if (!flags.confirm && !await cli_ux_1.default.confirm('Are you sure?'))
            return [];
        this.spinner.start('Delete service');
        for (const arg of argv) {
            this.spinner.status = arg;
            await this.unaryCall('DeleteService', {
                serviceID: arg,
                deleteData: !flags['keep-data'],
            });
        }
        this.spinner.stop();
        return argv;
    }
}
ServiceDelete.description = 'Delete one or many services';
ServiceDelete.aliases = ['service:rm', 'service:destroy'];
ServiceDelete.flags = Object.assign({}, service_command_1.default.flags, { 'keep-data': command_1.flags.boolean({ description: 'Do not delete services\' persistent data' }), confirm: command_1.flags.boolean({ description: 'Confirm delete', default: false }) });
ServiceDelete.strict = false;
ServiceDelete.args = [{
        name: 'SERVICE',
        required: true,
        description: 'Hash or Sid'
    }];
exports.default = ServiceDelete;
