"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const ignore_1 = tslib_1.__importDefault(require("ignore"));
const path_1 = require("path");
const tar_1 = tslib_1.__importDefault(require("tar"));
const deployer_1 = tslib_1.__importDefault(require("../../deployer"));
const service_command_1 = tslib_1.__importDefault(require("../../service-command"));
class ServiceDeploy extends service_command_1.default {
    async run() {
        const { argv, flags } = this.parse(ServiceDeploy);
        this.spinner.start('Deploy service');
        let deployed = [];
        for (const url of argv) {
            this.spinner.status = 'Download sources';
            const path = await deployer_1.default(await this.processUrl(url));
            try {
                deployed.push(await new Promise((resolve, reject) => {
                    const stream = this.mesg.api.DeployService();
                    stream.on('error', (error) => {
                        throw error;
                    });
                    stream.on('data', (data) => this.handleDeploymentResponse(data, resolve, reject));
                    this.writeEnv(stream, flags.env);
                    this.createTar(path)
                        .on('end', () => stream.end(''))
                        .on('error', (error) => {
                        throw error;
                    })
                        .on('data', (chunk) => {
                        if (chunk.length > 0)
                            stream.write({ chunk });
                    });
                }));
            }
            catch (e) {
                this.error(e);
            }
        }
        this.spinner.stop(deployed.map((x) => x.sid).join(', '));
        return deployed;
    }
    createTar(path) {
        const mesgignore = path_1.join(path, '.mesgignore');
        const ig = ignore_1.default().add([
            '.git',
            ...(fs_1.existsSync(mesgignore) ? fs_1.readFileSync(mesgignore).toString().split('\n') : [])
        ]);
        return tar_1.default.create({
            cwd: path,
            filter: ig.createFilter(),
            strict: true,
            gzip: true,
            portable: true,
        }, fs_1.readdirSync(path))
            .on('error', (error) => {
            throw error;
        });
    }
    writeEnv(stream, envList) {
        if (!envList || envList.length === 0)
            return;
        const env = envList.reduce((prev, item) => {
            const [key, value] = item.split('=');
            return Object.assign({}, prev, { [key]: value });
        }, {});
        stream.write({ env });
    }
    handleDeploymentResponse(x, resolve, reject) {
        if (x.status) {
            this.spinner.status = x.status.message;
            return;
        }
        return x.service ? resolve(x.service) : reject(x.validationError);
    }
    async processUrl(url) {
        const marketplaceUrl = url.split('mesg://marketplace/service/');
        if (marketplaceUrl.length === 2) {
            const versionHash = marketplaceUrl[1];
            const { type, source } = await this.getAuthorizedServiceInfo('', versionHash);
            if (type === 'ipfs') {
                return `http://ipfs.app.mesg.com:8080/ipfs/${source}`; // tslint:disable-line:no-http-string
            }
            throw new Error(`unknown protocol '${type}'`);
        }
        return url;
    }
}
ServiceDeploy.description = 'Deploy a service';
ServiceDeploy.flags = Object.assign({}, service_command_1.default.flags, { env: command_1.flags.string({
        description: 'set env defined in mesg.yml (configuration.env)',
        multiple: true,
        helpValue: 'FOO=BAR'
    }) });
ServiceDeploy.strict = false;
ServiceDeploy.args = [{
        name: 'SERVICE_PATH_OR_URL',
        description: 'Path of the service or url to access it',
        default: './'
    }];
exports.default = ServiceDeploy;
