"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const service_command_1 = tslib_1.__importDefault(require("../../service-command"));
const delete_1 = tslib_1.__importDefault(require("./delete"));
const deploy_1 = tslib_1.__importDefault(require("./deploy"));
const logs_1 = tslib_1.__importDefault(require("./logs"));
const start_1 = tslib_1.__importDefault(require("./start"));
class ServiceDev extends service_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceDev);
        const envs = (flags.env || []).reduce((prev, value) => [
            ...prev,
            '--env',
            value
        ], []);
        const services = (await deploy_1.default.run([args.SERVICE_PATH, ...envs]));
        const hashes = services.map(x => x.hash);
        await start_1.default.run(hashes);
        const stream = await logs_1.default.run(hashes);
        process.on('SIGINT', async () => {
            try {
                await delete_1.default.run([...hashes, '--keep-data', '--confirm']);
            }
            finally {
                process.exit(0);
            }
        });
        return stream;
    }
}
ServiceDev.description = 'Run your service in development mode';
ServiceDev.flags = Object.assign({}, service_command_1.default.flags, logs_1.default.flags, deploy_1.default.flags);
ServiceDev.args = [{
        name: 'SERVICE_PATH',
        description: 'Path of the service',
        default: './'
    }];
exports.default = ServiceDev;
