"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const service_command_1 = tslib_1.__importDefault(require("../../service-command"));
const detail_1 = tslib_1.__importDefault(require("./detail"));
class ServiceExecute extends service_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceExecute);
        const service = (await detail_1.default.run([args.SERVICE, '--silent']))[0];
        const task = service.definition.tasks.find((x) => x.key === args.TASK);
        if (!task) {
            this.error(`The task ${args.TASK} does not exists in the service ${args.SERVICE}`);
            return null;
        }
        const inputs = this.convertValue(task.inputs, this.dataFromFlags(flags));
        const result = await this.executeAndCaptureError(service.definition.hash, args.TASK, inputs);
        this.log(`Result of task ${args.TASK}`);
        this.styledJSON(result.data);
        return result;
    }
    dataFromFlags(flags) {
        if (flags.json) {
            return JSON.parse(fs_1.readFileSync(flags.json).toString());
        }
        return (flags.data || []).reduce((acc, item) => {
            const [key, value] = item.split('=');
            return Object.assign({}, acc, { [key]: value });
        }, {});
    }
    convertValue(inputs, data) {
        if (!inputs)
            return {};
        return inputs
            .filter((x) => !!data[x.key])
            .reduce((prev, value) => (Object.assign({}, prev, { [value.key]: this.convert(value.type, data[value.key]) })), {});
    }
    convert(type, value) {
        try {
            return {
                Object: (x) => typeof x === 'string' ? JSON.parse(x) : x,
                String: (x) => x,
                Boolean: (x) => ['true', 't', 'TRUE', 'T', '1'].includes(x),
                Number: (x) => parseFloat(x),
                Any: (x) => x,
            }[type](value);
        }
        catch (_a) {
            this.warn(`Cannot parse ${value} in ${type}`);
            return value;
        }
    }
}
ServiceExecute.description = 'describe the command here';
ServiceExecute.aliases = ['service:exec'];
ServiceExecute.flags = Object.assign({}, service_command_1.default.flags, { json: command_1.flags.string({ char: 'j', description: 'Path to a JSON file containing the data required to run the task' }), data: command_1.flags.string({
        char: 'd',
        description: 'data required to run the task',
        multiple: true,
        helpValue: 'FOO=BAR'
    }) });
ServiceExecute.args = [{
        name: 'SERVICE',
        required: true,
        description: 'Hash or Sid'
    }, {
        name: 'TASK',
        required: true,
        description: 'Task key'
    }];
exports.default = ServiceExecute;
