"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const service_command_1 = tslib_1.__importDefault(require("../../service-command"));
class ServiceLog extends service_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceLog);
        const stream = this.mesg.api.ServiceLogs({
            serviceID: args.SERVICE,
            dependencies: flags.dependency,
        });
        stream.on('data', response => {
            const dependency = response.dependency;
            this.log(chalk_1.default.yellow(dependency + ' | '), response.data.toString().replace('\n', ''));
        });
        stream.on('error', (error) => {
            throw error;
        });
        if (!flags['no-results']) {
            const tasks = flags.task || [];
            this.mesg.api.ListenResult({ serviceID: args.SERVICE })
                .on('data', (data) => {
                if (tasks.length > 0 && !tasks.includes(data.taskKey))
                    return;
                this.log(this.formatResult(data));
            })
                .on('error', (error) => {
                throw error;
            });
        }
        if (!flags['no-events']) {
            const events = flags.event || [];
            this.mesg.api.ListenEvent({ serviceID: args.SERVICE })
                .on('data', (data) => {
                if (events.length > 0 && !events.includes(data.evenKey))
                    return;
                this.log(this.formatEvent(data));
            })
                .on('error', (error) => {
                throw error;
            });
        }
        return stream;
    }
    formatEvent(event) {
        return `EVENT[${event.eventKey}]: ` + chalk_1.default.gray(event.eventData);
    }
    formatResult(result) {
        if (result.error) {
            return `RESULT[${result.taskKey}]: ` + chalk_1.default.red('ERROR:', result.error);
        }
        return `RESULT[${result.taskKey}]: ` + chalk_1.default.gray(result.outputData);
    }
}
ServiceLog.description = 'Show logs of a service';
ServiceLog.flags = Object.assign({}, service_command_1.default.flags, { dependency: command_1.flags.string({
        char: 'd',
        description: 'Name of the dependency to show the logs from',
        multiple: true
    }), 'no-events': command_1.flags.boolean({
        description: 'Remove events from the logs'
    }), 'no-results': command_1.flags.boolean({
        description: 'Remove results from the logs'
    }), event: command_1.flags.string({
        description: 'Filter specific events in the logs',
        multiple: true
    }), task: command_1.flags.string({
        description: 'Filter specific task results in the logs',
        multiple: true
    }) });
ServiceLog.args = [{
        name: 'SERVICE',
        required: true,
        description: 'Hash or Sid'
    }];
exports.default = ServiceLog;
