"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const inquirer_1 = require("inquirer");
const root_command_1 = tslib_1.__importDefault(require("./root-command"));
const services_1 = tslib_1.__importDefault(require("./services"));
class MarketplaceCommand extends root_command_1.default {
    async sign(account, data, passphrase) {
        const res = await this.executeAndCaptureError(services_1.default.account.id, services_1.default.account.tasks.sign, {
            passphrase,
            address: account,
            transaction: data,
        });
        return res.data;
    }
    async getAccount() {
        const { flags } = this.parse();
        if (flags.account) {
            return flags.account;
        }
        const list = await this.executeAndCaptureError(services_1.default.account.id, services_1.default.account.tasks.list);
        this.require(list.data.addresses.length > 0, 'You need to create an account first.');
        if (list.data.addresses.length === 1) {
            return list.data.addresses[0];
        }
        const { account } = (await inquirer_1.prompt({
            type: 'list',
            name: 'account',
            message: 'Choose the account to use to publish your service',
            choices: list.data.addresses
        }));
        return account;
    }
    async getPassphrase() {
        const { flags } = this.parse();
        if (flags.passphrase) {
            return flags.passphrase;
        }
        return cli_ux_1.cli.prompt('Type your passphrase', { type: 'hide' });
    }
}
MarketplaceCommand.flags = Object.assign({}, root_command_1.default.flags, { account: command_1.flags.string({
        char: 'a',
        description: 'Account to use'
    }), passphrase: command_1.flags.string({
        char: 'p',
        description: 'Passphrase to unlock your account'
    }) });
exports.default = MarketplaceCommand;
