"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const protoLoader = tslib_1.__importStar(require("@grpc/proto-loader"));
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const grpc = tslib_1.__importStar(require("grpc"));
const mesg_js_1 = require("mesg-js");
const grpc_1 = require("mesg-js/lib/util/grpc");
const path_1 = require("path");
const util_1 = require("util");
class default_1 extends command_1.Command {
    constructor() {
        super(...arguments);
        this._mesg = null;
    }
    get engineEndpoint() {
        const host = process.env.DOCKER_HOST
            ? new URL(process.env.DOCKER_HOST).hostname
            : 'localhost';
        return `${host}:50052`;
    }
    get mesg() {
        if (!this._mesg) {
            this._mesg = mesg_js_1.application({ endpoint: this.engineEndpoint });
        }
        return this._mesg;
    }
    get serviceAPI() {
        if (!this._serviceAPI) {
            this._serviceAPI = this.createClient('ServiceX', 'api', 'service.proto', this.engineEndpoint);
        }
        return this._serviceAPI;
    }
    createClient(serviceName, dir, file, endpoint) {
        const packageDefinition = protoLoader.loadSync(path_1.join(__dirname, './protobuf', dir, file), {
            includeDirs: [__dirname]
        });
        const packageObject = grpc.loadPackageDefinition(packageDefinition);
        const clientConstructor = packageObject[dir][serviceName];
        return new clientConstructor(endpoint, grpc.credentials.createInsecure());
    }
    get spinner() {
        const { flags } = this.parse();
        const nope = () => { };
        if (flags.quiet) {
            return { start: nope, stop: (message) => message ? this.log(message) : null, status: null };
        }
        if (flags.silent) {
            return { start: nope, stop: nope, status: null };
        }
        return cli_ux_1.cli.action;
    }
    require(condition, errorMessage) {
        if (!condition) {
            throw new Error(errorMessage);
        }
    }
    log(message, ...args) {
        if (this.parse) {
            const { flags } = this.parse();
            if (flags.silent) {
                return;
            }
        }
        message = typeof message === 'string' ? message : util_1.inspect(message);
        process.stdout.write(util_1.format(message, ...args) + '\n');
    }
    styledJSON(data) {
        const { flags } = this.parse();
        if (flags.silent)
            return;
        cli_ux_1.cli.styledJSON(data);
    }
    async executeAndCaptureError(serviceID, taskKey, data = {}, tags = []) {
        this.debug(`Execute task ${taskKey} from ${serviceID} with ${JSON.stringify(data)}`);
        try {
            const result = await this.mesg.executeTaskAndWaitResult({
                serviceID,
                taskKey,
                inputData: JSON.stringify(data),
                executionTags: [...tags, 'cli']
            });
            this.debug(`Receiving result of ${result.executionHash}, ${result.taskKey} => ${result.outputData}`);
            if (result.error) {
                throw new Error(result.error);
            }
            return {
                data: JSON.parse(result.outputData)
            };
        }
        catch (e) {
            this.error(e.message);
            throw new Error(e.message);
        }
    }
    async unaryCall(method, data = {}) {
        this.debug(`Call MESG Engine API ${method} with ${JSON.stringify(data)}`);
        return new Promise((resolve, reject) => this.mesg.api[method](data, (error, res) => error
            ? reject(error)
            : resolve(res)));
    }
    listenEvent(serviceID, event) {
        this.debug(`Listening to events ${event} from ${serviceID}`);
        const stream = this.mesg.listenEvent({
            eventFilter: event,
            serviceID
        });
        return stream
            .on('error', (err) => {
            stream.cancel();
            throw err;
        })
            .on('metadata', metadata => {
            const err = grpc_1.checkStreamReady(metadata);
            if (err === grpc_1.errNoStatus)
                return;
            if (err) {
                stream.destroy(err);
                return;
            }
        });
    }
}
default_1.flags = {
    help: command_1.flags.help({ char: 'h' }),
    quiet: command_1.flags.boolean({ char: 'q' }),
    silent: command_1.flags.boolean(),
};
exports.default = default_1;
