import Command from './root-command';
export interface ServiceID {
    sid: string;
    hash: string;
}
export interface Service {
    definition: Definition;
    status: number;
}
export interface CompiledDefinition {
    sid: string;
    name: string;
    description: string;
    tasks: Task[];
    events: Event[];
    dependencies: Dependency[];
    configuration: Dependency;
    repository: string;
    source: string;
}
export interface Definition extends CompiledDefinition {
    hash: string;
}
export interface Task {
    key: string;
    name: string;
    description: string;
    inputs: Parameter[];
    outputs: Parameter[];
}
export interface Event {
    key: string;
    name: string;
    description: string;
    data: Parameter[];
}
export interface Dependency {
    key: string;
    image: string;
    volumes: string[];
    volumesFrom: string[];
    ports: string[];
    command: string;
    args: string[];
    env: string[];
}
export interface Parameter {
    name: string;
    description: string;
    type: string;
    optional: boolean;
    repeated: boolean;
    object: Parameter[];
}
export declare type SERVICE_PARAMETER_TYPE = 'String' | 'Number' | 'Boolean' | 'Object' | 'Any';
export interface ServiceInfo {
    sid: string;
    source: string;
    type: string;
}
export default abstract class extends Command {
    static flags: {
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        quiet: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
        silent: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
    };
    status(s: number): string;
    getAuthorizedServiceInfo(id: string, versionHash: string): Promise<ServiceInfo>;
}
